# Calculator

A simple Python library that allows you to do mathematical calculations from strings, using regex validation.

## Installazione

```bash
pip install Calculator2
```

## Example

```python
from Calculator import calc

test = calc("2+2 * 2")
print(test)
```
